from django.conf import settings
from django.contrib.auth.models import Group, Permission
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = "add permissions"

    def handle(self, *args, **options):
        program_group = Group.objects.get(name=settings.PRIVILEGED_GROUP)
        app_permissions = Permission.objects.filter(content_type__app_label="program").exclude(
            codename__startswith="edit"
        )
        self.stdout.write(
            f"Adding app permissions to the '{program_group}' group... ",
            ending="",
        )
        self.stdout.flush()
        program_group.permissions.add(*app_permissions)
        self.stdout.write(self.style.SUCCESS(str(len(app_permissions))))

        host_group = Group.objects.get(name=settings.ENTITLED_GROUPS[0])
        model_permissions = Permission.objects.filter(
            content_type__model__in=["note", "notelink"]
        ).exclude(codename__startswith="edit")
        self.stdout.write(
            f"Adding model permissions on note & notelink to the '{host_group}' group... ",
            ending="",
        )
        self.stdout.flush()
        host_group.permissions.add(*model_permissions)
        self.stdout.write(self.style.SUCCESS(str(len(model_permissions))))

        host_plus_group = Group.objects.get(name=settings.ENTITLED_GROUPS[1])
        change_permissions = Permission.objects.filter(
            codename__startswith="change", content_type__model__in=["host", "note", "show"]
        )
        self.stdout.write(
            f"Adding change permissions on host, note & show to the '{host_plus_group}' group... ",
            ending="",
        )
        host_plus_group.permissions.add(*change_permissions)
        self.stdout.write(self.style.SUCCESS(str(len(change_permissions))))
        self.stdout.flush()
        edit_permissions = Permission.objects.filter(
            codename__startswith="edit", content_type__model__in=["host", "note", "show"]
        )
        self.stdout.write(
            f"Adding edit permissions on host, note & show to the '{host_plus_group}' group... ",
            ending="",
        )
        self.stdout.flush()
        host_plus_group.permissions.add(*edit_permissions)
        self.stdout.write(self.style.SUCCESS(str(len(edit_permissions))))

        self.stdout.write(
            f"Adding edit permissions on host, note & show to the '{program_group}' group... ",
            ending="",
        )
        self.stdout.flush()
        program_group.permissions.add(*edit_permissions)
        self.stdout.write(self.style.SUCCESS(str(len(edit_permissions))))
